Name:		connman
Version:	1.38
%define subrel 4
Release:	%mkrel 2
Summary:	Connection Manager
Group:		Networking/Other
License:	GPLv2
URL:		https://01.org/connman
Source0:	http://www.kernel.org/pub/linux/network/%{name}/%{name}-%{version}.tar.xz
Source1:	README.urpmi
Patch1:		connman-1.21-fix-polkit-detection.patch
#(eatdirt): the tmpfile makes a symlink to /etc/resolv.conf, which
#after deinstallation of connman is dangling and breaks all the other
#network manager. We remove the creation of the symlink (connman should find
#its own resolv.conf in /var/run/connman)
Patch3:		connman-1.33-nosymlink-resolvconf.patch
Patch4:		CVE-2021-26675.patch
Patch5:		CVE-2021-26676.patch
Patch6:		CVE-2021-33833.patch
Patch7:		0001_dnsproxy_Validate_input_data_before_using_them.patch
Patch8:		0002_dnsproxy_Update_TCP_length_header.patch
Patch9:		0003_dnsproxy_Avoid_100_busy_loop_in_TCP_server_case.patch
Patch10:	0004_dnsproxy_Keep_timeout_in_TCP_case_even_after_connect.patch
Patch11:	CVE-2022-32292.patch
Patch12:	CVE-2022-32293.patch
Patch13:	CVE-2023-28488.patch

BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(glib-2.0)
# for iptables-save check
BuildRequires:	iptables
BuildRequires:	pkgconfig(xtables)
BuildRequires:	openconnect
BuildRequires:	openvpn
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	pkgconfig(libmnl)
BuildRequires:	pkgconfig(polkit-agent-1)
BuildRequires:	ppp-devel
BuildRequires:	readline-devel
BuildRequires:	pkgconfig(systemd)
BuildRequires:	pkgconfig(udev)
BuildRequires:	vpnc
# for wpa_supplicant check
BuildRequires:  wpa_supplicant
Requires:	openvpn openconnect vpnc
Requires:	dbus
Requires:	wpa_supplicant >= 0.5.7
Requires:	bluez

Requires(post):   rpm-helper >= %{rpmhelper_required_version}
Requires(preun):  rpm-helper >= %{rpmhelper_required_version}

%description
Connection Manager provides a daemon for managing Internet connections
within embedded devices running the Linux operating system.

%package devel
Summary:	Development files for Connection Manager
Group:		Development/C
Requires:	%{name} >= %{version}

%description devel
connman-devel contains development files for use with connman.

%prep
%setup -q
%autopatch -p1

# README.urpmi
install -pm644 %{_sourcedir}/README.urpmi .

%build
autoreconf -fi
%configure	--disable-static \
		--enable-ethernet \
		--enable-wifi \
		--enable-bluetooth \
		--enable-datafiles \
		--enable-loopback \
		--enable-client \
		--enable-hh2serial-gps \
		--enable-openvpn \
		--enable-openconnect \
		--enable-vpnc \
		--enable-l2tp \
		--enable-iospm \
		--enable-tist \
		--enable-nmcompat \
		--enable-polkit \
		--runstatedir=%{_rundir}
%make_build

%install
%make_install

%__install -Dpm644 src/connman.service %{buildroot}%{_datadir}/dbus-1/system-services/org.moblin.connman.service

# we don't want these
find %{buildroot} -name "*.la" -delete

# (wally) don't enable connman by default as it can cause problems if
# networkmanager is also running. People wanting to test/use connman
# should stop/disable other network managers by themselves before enabling
# connman
#post
#_post_service %%{name}

%preun
%_preun_service %{name}
# this guy get started via bus and remains after deinstallation otherwise
%_preun_service %{name}-vpn

%files
%doc AUTHORS COPYING ChangeLog NEWS README
%doc README.urpmi
%{_bindir}/connmanctl
%{_sbindir}/*
%dir %{_libdir}/%{name}/scripts/
%{_libdir}/%{name}/scripts/libppp-plugin.so
%{_libdir}/%{name}/scripts/openvpn-script
%{_libdir}/%{name}/scripts/vpn-script
%dir %{_libdir}/%{name}/plugins/
%{_libdir}/%{name}/plugins/hh2serial-gps.so
%{_libdir}/%{name}/plugins/iospm.so
%{_libdir}/%{name}/plugins/tist.so
%dir %{_libdir}/%{name}/plugins-vpn/
%{_libdir}/%{name}/plugins-vpn/l2tp.so
%{_libdir}/%{name}/plugins-vpn/openconnect.so
%{_libdir}/%{name}/plugins-vpn/openvpn.so
%{_libdir}/%{name}/plugins-vpn/vpnc.so
%{_libdir}/%{name}/plugins-vpn/wireguard.so
# %%{_sysconfdir}/dbus-1/system.d/*.conf
%{_datadir}/dbus-1/system.d/*.conf
%{_datadir}/dbus-1/system-services/net.connman.vpn.service
%{_datadir}/dbus-1/system-services/org.moblin.connman.service
%{_datadir}/polkit-1/actions/net.%{name}.policy
%{_datadir}/polkit-1/actions/net.%{name}.vpn.policy
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}-vpn.service
%{_unitdir}/%{name}-wait-online.service
%{_tmpfilesdir}/connman_resolvconf.conf
%{_mandir}/man1/connmanctl.1*
%{_mandir}/man5/%{name}*.conf.5*
%{_mandir}/man5/%{name}*.config.5*
%{_mandir}/man8/%{name}.8*
%{_mandir}/man8/%{name}-vpn.8*

%files devel
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc


%changelog
* Sun May 07 2023 daviddavid <daviddavid> 1.38-2.4.mga8
+ Revision: 1956043
- add upstream patch to fix CVE-2023-28488 (mga#31878)
+ ns80 <ns80>
- backport upstream patches for CVE-2022-3229[23] (mga#30698)
- add patches for CVE-2022-2309[6-8] (mga#29945)
- add upstream patch for CVE-2021-33833 (mga#29124)

* Mon Feb 08 2021 daviddavid <daviddavid> 1.38-2.mga8
+ Revision: 1675059
- add upstream patches to fix CVE-2021-26675 and CVE-2021-26676 (mga#28321)

* Thu Dec 03 2020 luigiwalser <luigiwalser> 1.38-1.mga8
+ Revision: 1652004
- 1.38

* Wed Feb 19 2020 umeabot <umeabot> 1.37-3.mga8
+ Revision: 1542556
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Jan 05 2020 tv <tv> 1.37-2.mga8
+ Revision: 1476635
- rebuild for new readline

* Sun Apr 14 2019 daviddavid <daviddavid> 1.37-1.mga7
+ Revision: 1390023
- new version: 1.37

* Mon Mar 18 2019 daviddavid <daviddavid> 1.36-2.mga7
+ Revision: 1378616
- update tmpfiles configuration to use /run instead of /var/run

* Wed Sep 12 2018 shlomif <shlomif> 1.36-1.mga7
+ Revision: 1258664
- New version 1.36

* Tue Jan 02 2018 wally <wally> 1.35-2.mga7
+ Revision: 1189419
- rebuild for new readline

* Thu Oct 12 2017 shlomif <shlomif> 1.35-1.mga7
+ Revision: 1171246
- new version 1.35 fixing MGA#21629
+ wally <wally>
- drop unneeded requires for dhcp-client
- drop .la files

* Thu Feb 23 2017 wally <wally> 1.33-6.mga6
+ Revision: 1087515
- rephrase README.urpmi a bit

* Thu Feb 23 2017 wally <wally> 1.33-5.mga6
+ Revision: 1087506
- don't enable connman.service by default as it causes conflicts/issues with networkmanager if both are enabled
- add README.urpmi

* Sat Jan 28 2017 luigiwalser <luigiwalser> 1.33-4.mga6
+ Revision: 1083736
- rebuild for libxtables (libiptables)

* Wed Nov 30 2016 eatdirt <eatdirt> 1.33-3.mga6
+ Revision: 1071331
- Fix remaining connman-vpn service after uninstall

* Wed Nov 30 2016 eatdirt <eatdirt> 1.33-2.mga6
+ Revision: 1071305
- Add patch to avoid symlinking /etc/resolv.conf

* Thu Aug 11 2016 luigiwalser <luigiwalser> 1.33-1.mga6
+ Revision: 1045484
- 1.33

* Mon May 09 2016 luigiwalser <luigiwalser> 1.32-1.mga6
+ Revision: 1011305
- add patch from debian to fix build due to bad commit in kernel (bdo#822393)
- 1.32

* Mon Jan 25 2016 luigiwalser <luigiwalser> 1.31-1.mga6
+ Revision: 927269
- 1.31

* Fri Jan 15 2016 luigiwalser <luigiwalser> 1.30-3.mga6
+ Revision: 923208
- rebuild for libxtables (libiptables)

* Mon Jan 11 2016 luigiwalser <luigiwalser> 1.30-2.mga6
+ Revision: 921798
- rebuild for gnutls

* Thu Sep 03 2015 shlomif <shlomif> 1.30-1.mga6
+ Revision: 872402
- New version 1.30
+ trem <trem>
- revert previous commis (always start service)
- always start connman at boot

* Wed Oct 15 2014 umeabot <umeabot> 1.24-4.mga5
+ Revision: 748692
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 1.24-3.mga5
+ Revision: 693675
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.24-2.mga5
+ Revision: 678527
- Mageia 5 Mass Rebuild

* Sun Jul 20 2014 trem <trem> 1.24-1.mga5
+ Revision: 654746
- bump version to 1.24

* Sat Mar 22 2014 trem <trem> 1.21-1.mga5
+ Revision: 606543
- bump to 1.21

* Sat Oct 19 2013 umeabot <umeabot> 1.14-3.mga4
+ Revision: 526594
- Mageia 4 Mass Rebuild

* Wed Jun 05 2013 fwang <fwang> 1.14-2.mga4
+ Revision: 437500
- rebuild for new iptables

* Sun May 26 2013 blino <blino> 1.14-1.mga4
+ Revision: 428131
- package man pages
- cherry-pick string format patch
- drop merged patch
- 1.14

* Mon Jan 14 2013 tmb <tmb> 1.10-2.mga3
+ Revision: 388077
- BR systemd-devel
- update filelists
- work around broken kernel-headers (P1)
+ dmorgan <dmorgan>
- New version
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 31 2012 wally <wally> 1.9-3.mga3
+ Revision: 336567
- fix build with new automake 1.13

* Sat Nov 17 2012 shlomif <shlomif> 1.9-2.mga3
+ Revision: 319200
- Missing BR
- New version 1.9

* Fri Nov 09 2012 fwang <fwang> 1.4-2.mga3
+ Revision: 316554
- fix linkage of scripts plugin
- rebuild for new xtables

* Thu Aug 16 2012 fedya <fedya> 1.4-1.mga3
+ Revision: 281489
- %%mkrel macro
- few rpmlint messages fix
- imported package connman

